# Generated by Django 2.1.7 on 2020-07-20 14:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0007_auto_20200716_1451'),
    ]

    operations = [
        migrations.AlterField(
            model_name='clienteerro',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clienteerro',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clienteerro',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientelog',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientelog',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientelog',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientequery',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientequery',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientequery',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorerro',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorerro',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorerro',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorlog',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorlog',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorlog',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorquery',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorquery',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorquery',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorerro',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorerro',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorerro',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorlog',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorlog',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorlog',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorquery',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorquery',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorquery',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoserro',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoserro',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoserro',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoslog',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoslog',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoslog',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processosquery',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processosquery',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processosquery',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maiserro',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maiserro',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maiserro',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maislog',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maislog',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maislog',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maisquery',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maisquery',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maisquery',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-15 23:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0008_auto_20200715_1931'),
    ]

    operations = [
        migrations.AlterField(
            model_name='produto',
            name='imagem',
            field=models.FileField(default='produtos/caixa-nissei.jpg', null=True, upload_to='produtos'),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='imagem',
            field=models.FileField(default='produtos/caixa-nissei.jpg', null=True, upload_to='produtos'),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-05 19:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0015_funcionario_imagem'),
    ]

    operations = [
        migrations.AlterField(
            model_name='funcionario',
            name='imagem',
            field=models.FileField(default='fotos/no-photo.png', null=True, upload_to='fotos/funcionarios'),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-28 20:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0017_auto_20200728_1525'),
    ]

    operations = [
        migrations.AddField(
            model_name='endereco',
            name='bairro',
            field=models.CharField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='endereco',
            name='rua',
            field=models.CharField(max_length=100, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-05 19:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0013_auto_20200731_1612'),
    ]

    operations = [
        migrations.AddField(
            model_name='municipio',
            name='faixa_fim',
            field=models.CharField(max_length=80, null=True),
        ),
        migrations.AddField(
            model_name='municipio',
            name='faixa_ini',
            field=models.CharField(max_length=80, null=True),
        ),
        migrations.AddField(
            model_name='uf',
            name='faixa_fim',
            field=models.CharField(max_length=80, null=True),
        ),
        migrations.AddField(
            model_name='uf',
            name='faixa_ini',
            field=models.CharField(max_length=80, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-28 16:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0011_auto_20200728_1233'),
    ]

    operations = [
        migrations.RenameField(
            model_name='cliente',
            old_name='celular',
            new_name='celular_completo_form',
        ),
        migrations.RenameField(
            model_name='cliente',
            old_name='telefone',
            new_name='telefone_completo_form',
        ),
        migrations.AddField(
            model_name='cliente',
            name='celular_completo',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='cliente',
            name='celular_numero',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='cliente',
            name='telefone_completo',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='cliente',
            name='telefone_nr',
            field=models.CharField(max_length=50, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-05 19:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0014_auto_20200805_1652'),
    ]

    operations = [
        migrations.RenameField(
            model_name='municipio',
            old_name='faixa_fim',
            new_name='cep_faixa_fim',
        ),
        migrations.RenameField(
            model_name='municipio',
            old_name='faixa_ini',
            new_name='cep_faixa_ini',
        ),
        migrations.RenameField(
            model_name='uf',
            old_name='faixa_fim',
            new_name='cep_faixa_fim',
        ),
        migrations.RenameField(
            model_name='uf',
            old_name='faixa_ini',
            new_name='cep_faixa_ini',
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-28 17:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0014_auto_20200728_1413'),
    ]

    operations = [
        migrations.AddField(
            model_name='termo',
            name='ordem',
            field=models.IntegerField(null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-06 21:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('usr', '0009_auto_20200805_1705'),
    ]

    operations = [
        migrations.AlterField(
            model_name='grupo',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='grupouser',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-16 16:51

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0005_auto_20200716_1347'),
        ('filial', '0006_auto_20200716_1348'),
    ]

    operations = [
        migrations.AddField(
            model_name='servico',
            name='tipo',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_servico_tipo', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('tipo_codigo'), 'tipo': compositefk.fields.LocalFieldValue('tipo_tipo')}),
        ),
        migrations.AddField(
            model_name='servico',
            name='tipo_codigo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='servico',
            name='tipo_tipo',
            field=models.CharField(default='FILIAL.SERVICO', max_length=200, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-20 14:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sistema', '0007_auto_20200716_1451'),
    ]

    operations = [
        migrations.AlterField(
            model_name='modulo',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='modulo',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='modulo',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfil',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfil',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfil',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfilgrupo',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfilgrupo',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfilgrupo',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfillogin',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfillogin',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfillogin',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfilpontofuncao',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfilpontofuncao',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='perfilpontofuncao',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='pontofuncao',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='pontofuncao',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='pontofuncao',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='versao',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='versao',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='versao',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='versao',
            name='responsavel_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='versaoitem',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='versaoitem',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='versaoitem',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='versaoitem',
            name='responsavel_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-10 18:20

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('core', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Filial',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('numero', models.CharField(max_length=30, null=True)),
                ('complemento', models.CharField(max_length=100, null=True)),
                ('ponto_referencia', models.CharField(max_length=100, null=True)),
                ('latitude', models.CharField(max_length=200, null=True)),
                ('longitude', models.CharField(max_length=200, null=True)),
                ('codigo', models.IntegerField(primary_key=True, serialize=False)),
                ('nome', models.CharField(max_length=200, null=True)),
                ('nome_completo', models.CharField(max_length=200, null=True)),
                ('cnpj', models.CharField(max_length=50, null=True)),
                ('telefone', models.CharField(max_length=50, null=True)),
                ('email', models.EmailField(max_length=200, null=True)),
                ('cep', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.Cep')),
                ('empresa', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='core.Empresa')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filial_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filial_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filial_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'filial',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='FilialHoraFuncionamento',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('is_padrao', models.BooleanField(default=True, null=True)),
                ('dat_ini_validade', models.DateField(null=True)),
                ('dat_fim_validade', models.DateTimeField(null=True)),
                ('cd_filial', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='filial.Filial')),
                ('cd_hr_dom_fim', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='cd_hr_dom_fim', to='core.Hora')),
                ('cd_hr_dom_inicio', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='cd_hr_dom_inicio', to='core.Hora')),
                ('cd_hr_sab_fim', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='cd_hr_sab_fim', to='core.Hora')),
                ('cd_hr_sab_inicio', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='cd_hr_sab_inicio', to='core.Hora')),
                ('cd_hr_util_fim', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='cd_hr_util_fim', to='core.Hora')),
                ('cd_hr_util_inicio', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='cd_hr_util_inicio', to='core.Hora')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filialhorafuncionamento_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filialhorafuncionamento_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filialhorafuncionamento_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'filial_horafuncionamento',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='FilialServico',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('filial', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='filial.Filial')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filialservico_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filialservico_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filialservico_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'filial_filialservico',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Servico',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
                ('descricao', models.TextField(null=True)),
                ('tipo_codigo', models.CharField(max_length=200, null=True)),
                ('tipo_tipo', models.CharField(default='FILIAL.SERVICO.TIPO', max_length=200, null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_servico_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_servico_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_servico_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
                ('tipo', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_servico_tipo', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('tipo_codigo'), 'tipo': compositefk.fields.LocalFieldValue('tipo_tipo')})),
            ],
            options={
                'db_table': 'filial_servico',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name='filialservico',
            name='servico',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='filial.Servico'),
        ),
        migrations.AddField(
            model_name='filial',
            name='servicos',
            field=models.ManyToManyField(through='filial.FilialServico', to='filial.Servico'),
        ),
    ]



from __future__ import annotations

from compositefk.fields import CompositeForeignKey
from django.db import models
from django.utils import timezone
import time

from core.util.core import Inteliger
from django.apps import apps


class InteligerQuerySet(models.QuerySet):
    def ativos(self):
        return self.filter(status=True)

    def desabilitar(self, request_=None):
        usuario = request_.user.id if request_ is not None else None
        qs = self.update(status=False, usr_delete=usuario, dat_delete=timezone.now())
        return qs


class InteligerManager(models.Manager):
    def get_queryset(self):
        ini = time.time()
        qs = InteligerQuerySet(self.model)
        fim = time.time()
        tempo = Inteliger().tempo_pesquisa
        if 0 < tempo < fim - ini:
            Query = apps.get_model('log', 'Query')
            Query(
                time=fim - ini,
                query=str(qs.query)
            ).save()

        return qs

    def ativos(self):
        return self.get_queryset().ativos()

    def desabilitar(self, request_=None):
        return self.get_queryset().desabilitar(request_=request_)


class DatLog(models.Model):
    dat_insercao = models.DateTimeField(auto_now_add=True, null=True, blank=True)
    dat_edicao = models.DateTimeField(auto_now=True, null=True, blank=True)
    dat_delete = models.DateTimeField(null=True, blank=True)

    class Meta:
        managed = False
        abstract = True


class UsrLog(models.Model):
    usr_insercao = models.IntegerField(null=True, blank=True)
    usr_edicao = models.IntegerField(null=True, blank=True)
    usr_delete = models.IntegerField(null=True, blank=True)

    origem_insercao_codigo = models.CharField(null=True, max_length=200, blank=True)
    origem_insercao_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE', blank=True)
    origem_insercao = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_origem_insercao', to_fields={
        "codigo": "origem_insercao_codigo",
        "tipo": "origem_insercao_tipo"
    })

    origem_edicao_codigo = models.CharField(null=True, max_length=200, blank=True)
    origem_edicao_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE', blank=True)
    origem_edicao = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_origem_edicao', to_fields={
        "codigo": "origem_edicao_codigo",
        "tipo": "origem_edicao_tipo"
    })

    origem_delete_codigo = models.CharField(null=True, max_length=200, blank=True)
    origem_delete_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE', blank=True)
    origem_delete = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_origem_delete', to_fields={
        "codigo": "origem_delete_codigo",
        "tipo": "origem_delete_tipo"
    })

    class Meta:
        managed = False
        abstract = True


class Log(DatLog, UsrLog):
    normal_objects = models.Manager()
    objects = InteligerManager()

    status = models.BooleanField(null=True, default=True)

    class Meta:
        managed = True
        abstract = True

    def save(self, request_=None, *args, **kwargs):
        if request_ is not None:
            if self.pk is None:
                self.usr_insercao = request_.user.id if request_ is not None else None
                self.dat_insercao = timezone.now()
                self.origem_insercao_codigo = request_.user.tipo_codigo if request_ is not None and request_.user.id is not None else None
                self.status = True
            else:
                self.usr_edicao = request_.user.id if request_ is not None else None
                self.dat_edicao = timezone.now()
                self.origem_codigo_codigo = request_.user.tipo_codigo if request_ is not None and request_.user.id is not None else None
        super(Log, self).save(*args, **kwargs)

    def desabilitar(self, request_=None, *args, **kwargs):
        self.status = False
        self.usr_delete_id = request_.user.id if request_ is not None else None
        self.dat_delete = timezone.now()
        self.origem_delete_codigo = request_.user.tipo_codigo if request_ is not None and request_.user.id is not None else None
        super(Log, self).save(*args, **kwargs)


class EmpresaLog(models.Model):
    empresa = models.ForeignKey('core.Empresa', on_delete=models.DO_NOTHING, null=True)

    class Meta(Log.Meta):
        abstract = True


class ContatoLog(models.Model):
    celular_numero = models.CharField(max_length=50, null=True)
    celular_ddd = models.CharField(max_length=3, null=True)
    celular_completo = models.CharField(max_length=50, null=True)
    celular_completo_form = models.CharField(max_length=50, null=True)

    telefone_numero = models.CharField(max_length=50, null=True)
    telefone_ddd = models.CharField(max_length=3, null=True)
    telefone_completo = models.CharField(max_length=50, null=True)
    telefone_completo_form = models.CharField(max_length=50, null=True)

    email = models.EmailField(max_length=200, null=True)

    class Meta(Log.Meta):
        abstract = True


class PessoaLog(ContatoLog):
    nm_completo = models.CharField(max_length=200, null=True)
    nm_primeiro = models.CharField(max_length=200, null=True)
    nm_ultimo = models.CharField(max_length=200, null=True)

    cpf = models.BigIntegerField(null=True)
    cpf_form = models.CharField(max_length=20, unique=True)

    rg = models.CharField(max_length=15, null=True)

    dat_nasc = models.DateField(null=True)

    imagem = models.FileField(upload_to='fotos/usuarios', default='fotos/sem-foto.png', null=True)

    nm_mae = models.CharField(max_length=200, null=True)
    nm_pai = models.CharField(max_length=200, null=True)

    sexo_codigo = models.CharField(null=True, max_length=200)
    sexo_tipo = models.CharField(null=True, max_length=200, default='PESSOA.SEXO')
    sexo = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_sexo', to_fields={
        "codigo": "sexo_codigo",
        "tipo": "sexo_tipo"
    })

    educacao_codigo = models.CharField(null=True, max_length=200)
    educacao_tipo = models.CharField(null=True, max_length=200, default='PESSOA.EDUCACAO')
    educacao = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_educacao', to_fields={
        "codigo": "educacao_codigo",
        "tipo": "educacao_tipo"
    })

    ocupacao_codigo = models.CharField(null=True, max_length=200)
    ocupacao_tipo = models.CharField(null=True, max_length=200, default='PESSOA.OCUPACAO')
    ocupacao = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_ocupacao', to_fields={
        "codigo": "ocupacao_codigo",
        "tipo": "ocupacao_tipo"
    })

    estado_civil_codigo = models.CharField(null=True, max_length=200)
    estado_civil_tipo = models.CharField(null=True, max_length=200, default='PESSOA.ESTADO_CIVIL')
    estado_civil = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_estado_civil', to_fields={
        "codigo": "estado_civil_codigo",
        "tipo": "estado_civil_tipo"
    })

    class Meta(Log.Meta):
        abstract = True


class EnderecoLog(models.Model):
    cep = models.CharField(max_length=10, null=True)
    cep_form = models.CharField(max_length=15, null=True)
    municipio = models.ForeignKey('core.Municipio', on_delete=models.DO_NOTHING, null=True)
    bairro_cep = models.CharField(max_length=100, null=True)
    endereco_cep = models.CharField(max_length=100, null=True)
    endereco_comp_cep = models.CharField(max_length=200, null=True)
    latitude_cep = models.CharField(max_length=200, null=True)
    longitude_cep = models.CharField(max_length=200, null=True)
    tipo_cep = models.CharField(max_length=200, null=True)


    class Meta(Log.Meta):
        abstract = True


class EnderecoComplementoLog(models.Model):
    cep = models.ForeignKey('core.Cep', null=True, on_delete=models.DO_NOTHING)
    numero = models.CharField(max_length=30, null=True)
    complemento = models.CharField(max_length=100, null=True)
    bairro = models.CharField(max_length=100, null=True)
    endereco = models.CharField(max_length=100, null=True)

    ponto_referencia = models.CharField(max_length=100, null=True)
    latitude = models.CharField(max_length=200, null=True)
    longitude = models.CharField(max_length=200, null=True)

    class Meta(Log.Meta):
        abstract = True


class Tipo(Log):
    codigo = models.IntegerField(null=True)
    tipo = models.CharField(max_length=200, null=True)
    nome = models.CharField(max_length=200, null=True)
    descricao = models.TextField(null=True)

    class Meta(Log.Meta):
        abstract = False
        db_table = 'tipo'
        unique_together = ('codigo', 'tipo')


class Empresa(Log):
    nome = models.CharField(max_length=100, null=True)

    class Meta(Log.Meta):
        abstract = False
        db_table = 'empresa'


class Erro(Log):
    nome = models.CharField(max_length=100)
    codigo = models.CharField(max_length=200, null=True)
    descricao = models.TextField(null=True)

    class Meta(Log.Meta):
        abstract = False
        db_table = 'erro'


class Data(Log):
    anomesdia = models.IntegerField(primary_key=True)
    anomes = models.IntegerField(null=True)
    ano = models.IntegerField(null=True)

    dat_dia = models.DateTimeField(null=True)

    nr_mes = models.IntegerField(null=True)
    ds_mes = models.CharField(max_length=50, null=True)
    ds_mes_abreviado = models.CharField(max_length=3, null=True)

    nr_dia = models.IntegerField(null=True)
    ds_dia_semana = models.CharField(max_length=50, null=True)

    nr_semana_ano = models.IntegerField(null=True)
    ds_semana_ano = models.CharField(max_length=50, null=True)

    nr_semana_mes = models.IntegerField(null=True)
    ds_semana_mes = models.CharField(max_length=50, null=True)

    nr_bimestre_ano = models.IntegerField(null=True)
    ds_bimestre_ano = models.CharField(max_length=50, null=True)

    nr_trimestre_ano = models.IntegerField(null=True)
    ds_trimestre_ano = models.CharField(max_length=50, null=True)

    nr_quadrimestre_ano = models.IntegerField(null=True)
    ds_quadrimestre_ano = models.CharField(max_length=50, null=True)

    nr_semestre_ano = models.IntegerField(null=True)
    ds_semestre_ano = models.CharField(max_length=50, null=True)

    nr_primeiro_dia_anomes = models.IntegerField(null=True)

    is_ultimo_dia_mes = models.BooleanField(null=True)
    ds_feriado_nacional = models.CharField(max_length=200, null=True)

    class Meta(Log.Meta):
        abstract = False
        db_table = 'data'


class Hora(Log):
    descricao = models.CharField(max_length=200, null=True)
    hora = models.IntegerField(null=True)
    minuto = models.IntegerField(null=True)
    hora_minuto = models.TimeField(null=True)
    cd_hora_minuto = models.IntegerField(null=True)

    class Meta(Log.Meta):
        abstract = False
        db_table = 'hora'


class UF(Log):
    codigo = models.IntegerField(primary_key=True)
    nome = models.CharField(max_length=200, null=True)
    nm_abrev = models.CharField(max_length=2, null=True)
    cep_faixa_ini = models.CharField(max_length=80, null=True)
    cep_faixa_fim = models.CharField(max_length=80, null=True)

    class Meta(Log.Meta):
        abstract = False
        db_table = 'uf'


class Municipio(Log):
    uf = models.ForeignKey('core.UF', on_delete=models.DO_NOTHING, null=True)
    codigo = models.IntegerField(primary_key=True)
    nome = models.CharField(max_length=200)
    cep_faixa_ini = models.CharField(max_length=80, null=True)
    cep_faixa_fim = models.CharField(max_length=80, null=True)

    class Meta(Log.Meta):
        abstract = False
        db_table = 'municipio'


class Cep(Log, EnderecoLog):
    cep = models.CharField(max_length=10, primary_key=True)

    class Meta(Log.Meta):
        abstract = False
        db_table = 'cep'


# Generated by Django 2.1.7 on 2020-08-05 19:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0027_auto_20200805_1642'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='estoquerede',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='estoquerede',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='estoquerede',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='estoquerede',
            name='produto',
        ),
        migrations.AddField(
            model_name='grupo',
            name='descricao',
            field=models.CharField(max_length=500, null=True),
        ),
        migrations.DeleteModel(
            name='EstoqueRede',
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-05 19:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0026_marca_nome_emarca'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='marca',
            name='nome_emarca',
        ),
        migrations.RemoveField(
            model_name='produto',
            name='marca_ecommerce',
        ),
        migrations.AddField(
            model_name='marca',
            name='nm_ecommerce',
            field=models.CharField(max_length=200, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-05 19:32

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0024_auto_20200805_1632'),
    ]

    operations = [
        migrations.AddField(
            model_name='produto',
            name='tipo_produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Tipo'),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-22 21:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0021_auto_20200722_0236'),
    ]

    operations = [
        migrations.RenameField(
            model_name='desconto',
            old_name='qtd_desc',
            new_name='qtd_fim_desc',
        ),
        migrations.AddField(
            model_name='desconto',
            name='qtd_ini_desc',
            field=models.IntegerField(null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-22 01:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0019_auto_20200721_1412'),
    ]

    operations = [
        migrations.AddField(
            model_name='tipodesconto',
            name='tipo',
            field=models.CharField(max_length=10, null=True),
        ),
    ]



from django.contrib.auth.base_user import AbstractBaseUser, BaseUserManager
from django.db import models
from django.utils import timezone

import core.models
from django.contrib.auth.models import UserManager, PermissionsMixin, Permission, Group
from compositefk.fields import CompositeForeignKey
from django.utils.translation import gettext_lazy as _

class Profile(AbstractBaseUser, core.models.Log, PermissionsMixin):
    username = models.CharField(max_length=200, unique=True)
    USERNAME_FIELD = 'username'
    is_staff = models.BooleanField(null=True, default=False)

    objects = BaseUserManager()

    tipo_codigo = models.CharField(null=True, max_length=200)
    tipo_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE')
    tipo = CompositeForeignKey(core.models.Tipo, on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_tipo', to_fields={
        "codigo": "tipo_codigo",
        "tipo": "tipo_tipo"
    })

    origem_codigo = models.CharField(null=True, max_length=200)
    origem_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE')
    origem = CompositeForeignKey(core.models.Tipo, on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_origem', to_fields={
        "codigo": "origem_codigo",
        "tipo": "origem_tipo"
    })

    is_superuser = models.BooleanField(
        _('superuser status'),
        default=False,
        help_text=_(
            'Designates that this user has all permissions without '
            'explicitly assigning them.'
        ),
    )
    groups = models.ManyToManyField(
        Group,
        verbose_name=_('groups'),
        blank=True,
        help_text=_(
            'The groups this user belongs to. A user will get all permissions '
            'granted to each of their groups.'
        ),
        related_name="%(app_label)s_%(class)s_user_set",
        related_query_name="user",
    )
    user_permissions = models.ManyToManyField(
        Permission,
        verbose_name=_('user permissions'),
        blank=True,
        help_text=_('Specific permissions for this user.'),
        related_name="%(app_label)s_%(class)s_user_set",
        related_query_name="user",
    )

    class Meta(core.models.Log.Meta):
        abstract = True


class Grupo(core.models.Log):
    nivel = models.IntegerField(null=True)
    nome = models.CharField(max_length=200, primary_key=True)
    nm_descritivo = models.CharField(max_length=200, null=True)
    descricao = models.CharField(max_length=500, null=True)
    grupo_pai = models.ForeignKey('usr.Grupo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_grupo_pai')

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'usr_grupo'


class GrupoUser(core.models.Log):
    grupo = models.ForeignKey('usr.Grupo', on_delete=models.DO_NOTHING, null=True)

    usr_id = models.IntegerField(null=True)
    usr_codigo = models.CharField(null=True, max_length=200)
    usr_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE')
    usr = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_usr', to_fields={
        "codigo": "usr_codigo",
        "tipo": "usr_tipo"
    })

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'usr_grupouser'




# Generated by Django 2.1.7 on 2020-07-15 22:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0002_auto_20200713_0030'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cep',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='data',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='empresa',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='erro',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='hora',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='municipio',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='tipo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='uf',
            options={'managed': True},
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-05 19:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0022_auto_20200722_1848'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='produto',
            name='tipo_produto',
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-17 13:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0014_auto_20200716_1451'),
    ]

    operations = [
        migrations.AddField(
            model_name='produto',
            name='qtd_max_venda_ecommerce',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='qtd_min_venda_ecommerce',
            field=models.IntegerField(default=1, null=True),
        ),
    ]



from django.db import models
import core.models
import core.usr.models
# Create your models here.


class FuncionarioLogin(core.usr.models.Profile):
    funcionario = models.OneToOneField('funcionario.Funcionario', on_delete=models.DO_NOTHING, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'funcionario_login'


class Funcionario(core.models.Log, core.models.PessoaLog):
    matricula = models.CharField(max_length=200, primary_key=True)
    cargo = models.ForeignKey('funcionario.Cargo', on_delete=models.DO_NOTHING, null=True)
    imagem = models.FileField(upload_to='fotos/funcionarios', default='fotos/sem-foto.png', null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'funcionario'


class Cargo(core.models.Log):
    nome = models.CharField(max_length=200, primary_key=True)
    cargo_pai = models.ForeignKey('self', on_delete=models.DO_NOTHING, null=True)
    nm_descritivo = models.CharField(max_length=500, null=True)
    funcao = models.CharField(max_length=200, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'cargo'



# Generated by Django 2.1.7 on 2020-08-05 19:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0025_produto_tipo_produto'),
    ]

    operations = [
        migrations.AddField(
            model_name='marca',
            name='nome_emarca',
            field=models.CharField(max_length=60, null=True),
        ),
    ]



# Create your views here.


# class Permissoes:
#     def sessao(self, request):
#         return 0
#
#
#     def pontos_funcao(self, request):
#         return 0
#
#
#     def view_login(self, request):
#         return 0



# Generated by Django 2.1.7 on 2020-07-28 15:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0010_auto_20200720_1146'),
    ]

    operations = [
        migrations.AddField(
            model_name='cliente',
            name='celular_ddd',
            field=models.CharField(max_length=3, null=True),
        ),
        migrations.AddField(
            model_name='cliente',
            name='telefone_ddd',
            field=models.CharField(max_length=3, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-05 20:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('filial', '0016_auto_20200731_1612'),
    ]

    operations = [
        migrations.AlterField(
            model_name='filial',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-29 18:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0009_clienteintegracao_fornecedorintegracao_indicadorintegracao_processosintegracao_venda_maisintegracao'),
    ]

    operations = [
        migrations.RenameField(
            model_name='clienteintegracao',
            old_name='data',
            new_name='body',
        ),
        migrations.RenameField(
            model_name='fornecedorintegracao',
            old_name='data',
            new_name='body',
        ),
        migrations.RenameField(
            model_name='indicadorintegracao',
            old_name='data',
            new_name='body',
        ),
        migrations.RenameField(
            model_name='processosintegracao',
            old_name='data',
            new_name='body',
        ),
        migrations.RenameField(
            model_name='venda_maisintegracao',
            old_name='data',
            new_name='body',
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-20 14:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0009_endereco_cep'),
    ]

    operations = [
        migrations.AlterField(
            model_name='avaliacao',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='avaliacao',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='avaliacao',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cartao',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cartao',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cartao',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cliente',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cliente',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cliente',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientetermo',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientetermo',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientetermo',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cupom',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cupom',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cupom',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='endereco',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='endereco',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='endereco',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='favorito',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='favorito',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='favorito',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='receita',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='receita',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='receita',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='termo',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='termo',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='termo',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-16 15:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0009_auto_20200715_2049'),
    ]

    operations = [
        migrations.AddField(
            model_name='categoria',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='especialidade',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='grupo',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='kit',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='marca',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='principioativo',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='nm_ecommerce',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=200, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-29 16:52

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0011_auto_20200728_1746'),
        ('cliente', '0019_auto_20200728_1752'),
    ]

    operations = [
        migrations.CreateModel(
            name='CartaoBandeira',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.PROFILE', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.PROFILE', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.PROFILE', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=50, primary_key=True, serialize=False)),
                ('nm_descritivo', models.CharField(max_length=200, null=True)),
                ('imagem', models.FileField(default='bandeiras/sem-imagem.jpg', null=True, upload_to='bandeiras')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_cartaobandeira_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_cartaobandeira_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_cartaobandeira_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'cliente_cartaobandeira',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='CartaoBandeiraParcela',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.PROFILE', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.PROFILE', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.PROFILE', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('quantidade', models.IntegerField(default=1, null=True)),
                ('is_juros', models.BooleanField(default=False, null=True)),
                ('bandeira', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='cliente.CartaoBandeira')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_cartaobandeiraparcela_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_cartaobandeiraparcela_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_cartaobandeiraparcela_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'cliente_cartaobandeiraparcela',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name='cartao',
            name='adquirente',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_cartao_adquirente', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('tipo_codigo'), 'tipo': compositefk.fields.LocalFieldValue('tipo_tipo')}),
        ),
        migrations.AddField(
            model_name='cartao',
            name='adquirente_codigo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='adquirente_tipo',
            field=models.CharField(default='CLIENTE.CARTAO.ADQUIRENTE', max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='cartao_token',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='cliente_token',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='dat_val',
            field=models.CharField(max_length=5, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='nm_impresso',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='tipo',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_cartao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('tipo_codigo'), 'tipo': compositefk.fields.LocalFieldValue('tipo_tipo')}),
        ),
        migrations.AddField(
            model_name='cartao',
            name='tipo_codigo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='tipo_tipo',
            field=models.CharField(default='CLIENTE.CARTAO', max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='ultimos_4',
            field=models.CharField(max_length=4, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='bandeira',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='cliente.CartaoBandeira'),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-03 20:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0022_auto_20200803_1608'),
    ]

    operations = [
        migrations.AddField(
            model_name='cartao',
            name='is_principal',
            field=models.BooleanField(default=False, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-06 21:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sistema', '0009_auto_20200805_1705'),
    ]

    operations = [
        migrations.AlterField(
            model_name='modulo',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='perfil',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='perfilgrupo',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='perfillogin',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='perfilpontofuncao',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='pontofuncao',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='versao',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='versaoitem',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]



from django.db import models
import core.models


class Log(core.models.Log):
    status_code = models.IntegerField(null=True)
    reason_phrase = models.CharField(max_length=500, null=True)
    metodo = models.CharField(max_length=30, null=True)
    ip = models.GenericIPAddressField(null=True)
    path = models.CharField(max_length=500, null=True)
    session_key = models.CharField(max_length=200, null=True)
    body = models.TextField(null=True)

    info_user = models.TextField(null=True)
    info_user_navegador_familia = models.CharField(max_length=200, null=True)
    info_user_navegador_versao = models.CharField(max_length=50, null=True)
    info_user_aparelho_familia = models.CharField(max_length=200, null=True)
    info_user_aparelho_modelo = models.CharField(max_length=200, null=True)
    info_user_os_familia = models.CharField(max_length=200, null=True)
    info_user_os_versao = models.CharField(max_length=50, null=True)

    info_user_is_bot = models.BooleanField(null=True)
    info_user_is_email_client = models.BooleanField(null=True)
    info_user_is_mobile = models.BooleanField(null=True)
    info_user_is_pc = models.BooleanField(null=True)
    info_user_is_tablet = models.BooleanField(null=True)
    info_user_is_touch_capable = models.BooleanField(null=True)

    class Meta(core.models.Log.Meta):
        abstract = True


class Query(core.models.Log):
    time = models.FloatField(null=True)
    query = models.TextField(null=True)

    class Meta(core.models.Log.Meta):
        abstract = True


class Erro(core.models.Log):
    erro = models.ForeignKey('core.Erro', on_delete=models.DO_NOTHING, null=True)
    tipo = models.CharField(max_length=50, null=True)
    ip = models.CharField(max_length=100, null=True)
    descricao = models.TextField(null=True)

    class Meta(core.models.Log.Meta):
        abstract = True


class Integracao(core.models.Log):
    servico = models.CharField(max_length=200, null=True)
    tipo = models.CharField(max_length=200, null=True)
    url = models.CharField(max_length=500, null=True)
    headers = models.TextField(null=True)
    body = models.TextField(null=True)
    status_code = models.IntegerField(null=True)
    response = models.TextField(null=True)

    class Meta(core.models.Log.Meta):
        abstract = True


class ClienteLog(Log):
    class Meta(Log.Meta):
        abstract = False
        db_table = u'"log\".\"cliente_log"'


class ClienteQuery(Query):
    class Meta(Query.Meta):
        abstract = False
        db_table = u'"log\".\"cliente_query"'


class ClienteErro(Erro):
    class Meta(Erro.Meta):
        abstract = False
        db_table = u'"log\".\"cliente_erro"'


class ClienteIntegracao(Integracao):
    class Meta(Erro.Meta):
        abstract = False
        db_table = u'"log\".\"cliente_integracao"'


class IndicadorLog(Log):
    class Meta(Log.Meta):
        abstract = False
        db_table = u'"log\".\"indicador_log"'


class IndicadorQuery(Query):
    class Meta(Query.Meta):
        abstract = False
        db_table = u'"log\".\"indicador_query"'


class IndicadorErro(Erro):
    class Meta(Erro.Meta):
        abstract = False
        db_table = u'"log\".\"indicador_erro"'


class IndicadorIntegracao(Integracao):
    class Meta(Erro.Meta):
        abstract = False
        db_table = u'"log\".\"indicador_integracao"'


class FornecedorLog(Log):
    class Meta(Log.Meta):
        abstract = False
        db_table = u'"log\".\"fornecedor_log"'


class FornecedorQuery(Query):
    class Meta(Query.Meta):
        abstract = False
        db_table = u'"log\".\"fornecedor_query"'


class FornecedorErro(Erro):
    class Meta(Erro.Meta):
        abstract = False
        db_table = u'"log\".\"fornecedor_erro"'


class FornecedorIntegracao(Integracao):
    class Meta(Erro.Meta):
        abstract = False
        db_table = u'"log\".\"fornecedor_integracao"'


class Venda_maisLog(Log):
    class Meta(Log.Meta):
        abstract = False
        db_table = u'"log\".\"venda_mais_log"'


class Venda_maisQuery(Query):
    class Meta(Query.Meta):
        abstract = False
        db_table = u'"log\".\"venda_mais_query"'


class Venda_maisErro(Erro):
    class Meta(Erro.Meta):
        abstract = False
        db_table = u'"log\".\"venda_mais_erro"'


class Venda_maisIntegracao(Integracao):
    class Meta(Erro.Meta):
        abstract = False
        db_table = u'"log\".\"venda_mais_integracao"'


class ProcessosLog(Log):
    class Meta(Log.Meta):
        abstract = False
        db_table = u'"log\".\"processos_log"'


class ProcessosQuery(Query):
    class Meta(Query.Meta):
        abstract = False
        db_table = u'"log\".\"processos_query"'


class ProcessosErro(Erro):
    class Meta(Erro.Meta):
        abstract = False
        db_table = u'"log\".\"processos_erro"'


class ProcessosIntegracao(Integracao):
    class Meta(Erro.Meta):
        abstract = False
        db_table = u'"log\".\"processos_integracao"'


# Generated by Django 2.1.7 on 2020-07-15 22:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0002_auto_20200713_0030'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='avaliacao',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='cartao',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='cliente',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='clientetermo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='cupom',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='endereco',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='favorito',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='receita',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='termo',
            options={'managed': True},
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-10 18:20

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('core', '0001_initial'),
        ('usr', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Modulo',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.SlugField(max_length=100, primary_key=True, serialize=False)),
                ('nm_descritivo', models.CharField(max_length=200, null=True)),
                ('modulo_pai', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='sistema.Modulo')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_modulo_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_modulo_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_modulo_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'sistema_modulo',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Perfil',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nivel', models.IntegerField(null=True)),
                ('is_login', models.BooleanField(null=True)),
                ('is_staff', models.BooleanField(default=False)),
                ('nome', models.CharField(max_length=200, primary_key=True, serialize=False)),
                ('nm_descritivo', models.CharField(max_length=200, null=True)),
                ('descricao', models.CharField(max_length=500, null=True)),
            ],
            options={
                'db_table': 'sistema_grupo',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='PerfilGrupo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('grupo', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='usr.Grupo')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfilgrupo_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfilgrupo_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfilgrupo_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
                ('perfil', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='sistema.Perfil')),
            ],
            options={
                'db_table': 'sistema_perfilgrupo',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='PerfilLogin',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('view_inicial', models.CharField(max_length=200, null=True)),
                ('modulo', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='sistema.Modulo')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfillogin_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfillogin_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfillogin_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
                ('perfil', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='sistema.Perfil')),
            ],
            options={
                'db_table': 'sistema_perfillogin',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='PerfilPontoFuncao',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfilpontofuncao_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfilpontofuncao_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfilpontofuncao_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
                ('perfil', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='sistema.Perfil')),
            ],
            options={
                'db_table': 'sistema_grupopontofuncao',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='PontoFuncao',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('acao', models.CharField(max_length=100, primary_key=True, serialize=False)),
                ('codigo', models.IntegerField(null=True)),
                ('versao', models.CharField(max_length=10, null=True)),
                ('descricao', models.CharField(max_length=500, null=True)),
                ('lugares', models.TextField(null=True)),
                ('modulo', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='sistema.Modulo')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_pontofuncao_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_pontofuncao_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_pontofuncao_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'sistema_pontofuncao',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='Versao',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('dat_atualizacao', models.DateField(null=True)),
                ('codigo', models.CharField(max_length=100, null=True)),
                ('commit', models.CharField(max_length=50, null=True)),
                ('descricao', models.TextField(null=True)),
                ('responsavel_id', models.IntegerField(null=True)),
                ('responsavel_codigo', models.CharField(max_length=200, null=True)),
                ('responsavel_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('modulo', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='sistema.Modulo')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_versao_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_versao_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_versao_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
                ('responsavel', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_versao_responsavel', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('responsavel_codigo'), 'tipo': compositefk.fields.LocalFieldValue('responsavel_tipo')})),
            ],
            options={
                'db_table': 'sistema_versao',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='VersaoItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('ordem', models.IntegerField(null=True)),
                ('descricao', models.TextField(null=True)),
                ('responsavel_id', models.IntegerField(null=True)),
                ('responsavel_codigo', models.CharField(max_length=200, null=True)),
                ('responsavel_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_versaoitem_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_versaoitem_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_versaoitem_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
                ('responsavel', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_versaoitem_responsavel', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('responsavel_codigo'), 'tipo': compositefk.fields.LocalFieldValue('responsavel_tipo')})),
                ('versao', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='sistema.Versao')),
            ],
            options={
                'db_table': 'sistema_versaoitem',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name='perfilpontofuncao',
            name='pontofuncao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='sistema.PontoFuncao'),
        ),
        migrations.AddField(
            model_name='perfil',
            name='grupo',
            field=models.ManyToManyField(through='sistema.PerfilGrupo', to='usr.Grupo'),
        ),
        migrations.AddField(
            model_name='perfil',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfil_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='perfil',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfil_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='perfil',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='sistema_perfil_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='perfil',
            name='pontofuncao',
            field=models.ManyToManyField(through='sistema.PerfilPontoFuncao', to='sistema.PontoFuncao'),
        ),
    ]



from django.contrib.staticfiles.storage import ManifestStaticFilesStorage


class ForgivingManifestStaticFilesStorage(ManifestStaticFilesStorage):
    manifest_strict = False
    def hashed_name(self, name, content=None, filename=None):
        try:
            result = super().hashed_name(name, content, filename)
        except ValueError:
            # When the fille is missing, let's forgive and ignore that.
            result = name
        return result


# Generated by Django 2.1.7 on 2020-07-22 05:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0020_tipodesconto_tipo'),
    ]

    operations = [
        migrations.RenameField(
            model_name='produtoean',
            old_name='eab',
            new_name='ean',
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-03 19:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0021_auto_20200731_1612'),
    ]

    operations = [
        migrations.AddField(
            model_name='cartao',
            name='ano_val',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='cpf_titular_numero',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='mes_val',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='primeiros_6',
            field=models.CharField(max_length=6, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-16 16:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0011_auto_20200716_1205'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bula',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='categoria',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='desconto',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='descontorelacao',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='especialidade',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='grupo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='kit',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='marca',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='precolista',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='principioativo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produto',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtobula',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtocategoria',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtoean',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtoespecialidade',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtogrupo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtoimagem',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtokit',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtopreco',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtoprincipioativo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtotiporeceita',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='tipo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='tipodesconto',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='tiporeceita',
            options={'managed': True},
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-17 13:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0007_auto_20200716_1451'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='endereco',
            name='cep',
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-28 20:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0009_auto_20200720_1146'),
    ]

    operations = [
        migrations.AddField(
            model_name='cep',
            name='cep_form',
            field=models.CharField(max_length=15, null=True),
        ),
    ]



from compositefk.fields import CompositeForeignKey
from django.db import models
import core.models
# Create your models here.


class Filial(core.models.Log, core.models.EmpresaLog, core.models.EnderecoComplementoLog):
    cd_filial = models.IntegerField(primary_key=True)
    nome = models.CharField(max_length=200, null=True)
    nome_completo = models.CharField(max_length=200, null=True)
    cnpj = models.CharField(max_length=50, null=True)
    telefone = models.CharField(max_length=50, null=True)
    email = models.EmailField(max_length=200, null=True)

    servicos = models.ManyToManyField('filial.Servico', through='FilialServico', through_fields=('cd_filial', 'servico'))

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'filial'


class Servico(core.models.Log):
    nome = models.CharField(max_length=200, null=True)
    descricao = models.TextField(null=True)

    tipo_codigo = models.CharField(null=True, max_length=200)
    tipo_tipo = models.CharField(null=True, max_length=200, default='FILIAL.SERVICO')
    tipo = CompositeForeignKey(core.models.Tipo, on_delete=models.DO_NOTHING, null=True, related_name='filial_servico_tipo', to_fields={
        "codigo": "tipo_codigo",
        "tipo": "tipo_tipo"
    })

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'filial_servico'


class FilialServico(core.models.Log):
    servico = models.ForeignKey('filial.Servico', on_delete=models.DO_NOTHING, null=True)
    cd_filial = models.ForeignKey('filial.Filial', on_delete=models.DO_NOTHING, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'filial_filialservico'


class FilialHoraFuncionamento(core.models.Log):
    is_padrao = models.BooleanField(null=True, default=True)
    dat_ini_validade = models.DateField(null=True)
    dat_fim_validade = models.DateTimeField(null=True)

    cd_hr_util_inicio = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_util_inicio")
    cd_hr_util_fim = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_util_fim")
    cd_hr_sab_inicio = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_sab_inicio")
    cd_hr_sab_fim = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_sab_fim")
    cd_hr_dom_inicio = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_dom_inicio")
    cd_hr_dom_fim = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_dom_fim")
    cd_filial = models.ForeignKey('filial.Filial', on_delete=models.DO_NOTHING, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'filial_horafuncionamento'



# Generated by Django 2.1.7 on 2020-08-05 19:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0024_cartao_cartao_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='cliente',
            name='imagem',
            field=models.FileField(default='fotos/no-photo.png', null=True, upload_to='fotos/clientes'),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-15 22:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0006_auto_20200715_1930'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='preco',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='preco',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='preco',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='preco',
            name='produto',
        ),
        migrations.DeleteModel(
            name='Preco',
        ),
    ]



from __future__ import annotations

from typing import Optional

from django.apps import apps
try:
    from base.settings import DATABASES
except:
    DATABASES = {}


class InteligerMeta(type):
    _instance: Optional[Inteliger] = None

    def __call__(self) -> Inteliger:
        if self._instance is None:
            self._instance = super().__call__()
        return self._instance


class Inteliger(metaclass=InteligerMeta):
    def __init__(self):
        self.__tempo_pesquisa = 0
        self.atualizar_tempo_query()

    def salvar_log(self, request=None, response=None):
        try:
            if request.META.get('REMOTE_ADDR') != '127.0.0.1':
                db = DATABASES['default']['USER'].capitalize()
                log = apps.get_model('log', db + 'Log')
                log(
                    status_code=response.status_code,
                    reason_phrase=response.reason_phrase,
                    metodo=request.method,
                    ip=request.META.get('REMOTE_ADDR'),
                    path=request.path,
                    session_key=request.session.session_key,
                    body=str(request.body) if not request.POST.get('password') else '',
                    info_user=str(request.user_agent),
                    info_user_navegador_familia=request.user_agent.browser.family,
                    info_user_navegador_versao=request.user_agent.browser.version_string,
                    info_user_aparelho_familia=request.user_agent.device.family,
                    info_user_aparelho_modelo=request.user_agent.device.model,
                    info_user_os_familia=request.user_agent.os.family,
                    info_user_os_versao=request.user_agent.os.version_string,
                    info_user_is_bot=request.user_agent.is_bot,
                    info_user_is_email_client=request.user_agent.is_email_client,
                    info_user_is_mobile=request.user_agent.is_mobile,
                    info_user_is_pc=request.user_agent.is_pc,
                    info_user_is_tablet=request.user_agent.is_tablet,
                    info_user_is_touch_capable=request.user_agent.is_touch_capable,
                ).save(request_=request)
        except:
            pass

    def atualizar_tempo_query(self):
        tipo = apps.get_model('core', 'Tipo')
        tempo = tipo.normal_objects.values('nome').filter(tipo='SISTEMA.TEMPO_QUERY', status=True).order_by('-dat_insercao').first()
        try:
            self.tempo_pesquisa = int(tempo['nome']) if tempo is not None else 0
        except:
            pass

    @property
    def tempo_pesquisa(self):
        return self.__tempo_pesquisa

    @tempo_pesquisa.setter
    def tempo_pesquisa(self, value):
        self.__tempo_pesquisa = value

    @tempo_pesquisa.deleter
    def tempo_pesquisa(self):
        del self.__tempo_pesquisa



# Generated by Django 2.1.7 on 2020-08-05 19:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0023_remove_produto_tipo_produto'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tipo',
            name='id',
        ),
        migrations.AddField(
            model_name='tipo',
            name='nm_descritivo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='nome',
            field=models.CharField(default=1, max_length=100, primary_key=True, serialize=False),
            preserve_default=False,
        ),
    ]



from django.db import models
import core.models


# Create your models here.
class Fornecedor(core.models.Log):
    nome = models.CharField(max_length=200, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'fornecedor'


class Fabricante(core.models.Log):
    nome = models.CharField(max_length=200, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'fabricante'



# Generated by Django 2.1.7 on 2020-07-16 15:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0003_auto_20200715_1925'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='clienteerro',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='clientelog',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='clientequery',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='fornecedorerro',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='fornecedorlog',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='fornecedorquery',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='indicadorerro',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='indicadorlog',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='indicadorquery',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='processoserro',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='processoslog',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='processosquery',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='venda_maiserro',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='venda_maislog',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='venda_maisquery',
            options={'managed': False},
        ),
    ]
